require 'test/unit'
require 'chimps_fb_analyzer' 
require 'pathname'

class PlayScrapeTest < Test::Unit::TestCase
  Node = Struct.new(:text)

  def setup
    file = File.join File.dirname(__FILE__), 'support_files', 'facebook-samschock-end'
    @fb_analyzer = ChimpsFBAnalyzer::FBAnalyzer.new(file)
    @name = "John Doe"
    @array_length = ChimpsFBAnalyzer::FBAnalyzer::FB_STATS.count
  end

  def test_analyze_wall
    @fb_analyzer.analyze_wall.inspect
  end

  def test_scan_html_node_for_sharing_a_link
    text = "#{@name} shared a link"
    node = Node.new(text)

    current_data = Array.new(@array_length, 0)
    10.times do |n|
      current_data = @fb_analyzer.scan_html_node(node, current_data, @name)
      index = ChimpsFBAnalyzer::FBAnalyzer::FB_STATS.index("shared")

      assert_equal(n + 1, current_data[index])
    end
  end

  def test_scan_html_node_for_liking_a_page
    text = "#{@name} likes Zelda"
    node = Node.new(text)

    current_data = Array.new(@array_length, 0)
    10.times do |n|
      current_data = @fb_analyzer.scan_html_node(node, current_data, @name)
      index = ChimpsFBAnalyzer::FBAnalyzer::FB_STATS.index("likes a page")

      assert_equal(n + 1, current_data[index])
    end
  end

  def test_scan_html_node_for_going_to_a_place
    text = "#{@name} is going to Waffle House" 
    node = Node.new(text)

    current_data = Array.new(@array_length, 0)
    10.times do |n|
      current_data = @fb_analyzer.scan_html_node(node, current_data, @name)
      index = ChimpsFBAnalyzer::FBAnalyzer::FB_STATS.index("going to a place")

      assert_equal(n + 1, current_data[index])
    end
  end

  def test_scan_html_node_for_went_to_a_place
    text = "#{@name} went to to Waffle House" 
    node = Node.new(text)

    current_data = Array.new(@array_length, 0)
    10.times do |n|
      current_data = @fb_analyzer.scan_html_node(node, current_data, @name)
      index = ChimpsFBAnalyzer::FBAnalyzer::FB_STATS.index("went to a place")

      assert_equal(n + 1, current_data[index])
    end
  end

  def test_scan_html_node_joined_a_group
    text = "#{@name} joined Myspace"
    node = Node.new(text)

    current_data = Array.new(@array_length, 0)
    10.times do |n|
      current_data = @fb_analyzer.scan_html_node(node, current_data, @name)
      index = ChimpsFBAnalyzer::FBAnalyzer::FB_STATS.index("joined a group")

      assert_equal(n + 1, current_data[index])
    end
  end

  def test_scan_html_node_for_tagged_in_a_photo
    text = "#{@name} was tagged in Jane Doe's photo"
    node = Node.new(text)

    current_data = Array.new(@array_length, 0)
    10.times do |n|
      current_data = @fb_analyzer.scan_html_node(node, current_data, @name)
      index = ChimpsFBAnalyzer::FBAnalyzer::FB_STATS.index("was tagged in a photo")

      assert_equal(n + 1, current_data[index])
    end
  end

  def test_scan_html_node_for_new_friends
    text = "#{@name} and Jane Doe are now friends"
    node = Node.new(text)

    current_data = Array.new(@array_length, 0)
    10.times do |n|
      current_data = @fb_analyzer.scan_html_node(node, current_data, @name)
      index = ChimpsFBAnalyzer::FBAnalyzer::FB_STATS.index("is now friends")

      assert_equal(n + 1, current_data[index])
    end
  end

  def test_scan_html_node_for_change_profile_pic
    array = []
    array.push "#{@name} changed his profile picture"
    array.push "#{@name} changed her profile picture"
    node = Node.new(array.sample)

    current_data = Array.new(@array_length, 0)
    10.times do |n|
      node.text = array.sample
      current_data = @fb_analyzer.scan_html_node(node, current_data, @name)
      index = ChimpsFBAnalyzer::FBAnalyzer::FB_STATS.index("changed profile pic")

      assert_equal(n + 1, current_data[index])
    end
  end

  def test_scan_html_node_for_creating_an_event
    text = "#{@name} created Facebook"
    node = Node.new(text)

    current_data = Array.new(@array_length, 0)
    10.times do |n|
      current_data = @fb_analyzer.scan_html_node(node, current_data, @name)
      index = ChimpsFBAnalyzer::FBAnalyzer::FB_STATS.index("creates event")

      assert_equal(n + 1, current_data[index])
    end
  end

  def test_scan_html_node_for_adding_a_new_photo
    text = "#{@name} added a new photo to the album John"
    node = Node.new(text)

    current_data = Array.new(@array_length, 0)
    10.times do |n|
      current_data = @fb_analyzer.scan_html_node(node, current_data, @name)
      index = ChimpsFBAnalyzer::FBAnalyzer::FB_STATS.index("adds a new photo")

      assert_equal(n + 1, current_data[index])
    end
  end

  def test_scan_html_node_for_friend_writing_on_your_timeline
    text = "#{@name} wrote on your timeline"
    node = Node.new(text)

    current_data = Array.new(@array_length, 0)
    10.times do |n|
      current_data = @fb_analyzer.scan_html_node(node, current_data, @name)
      index = ChimpsFBAnalyzer::FBAnalyzer::FB_STATS.index("friend writes on timeline")

      assert_equal(n + 1, current_data[index])
    end
  end

  def test_write_data_to_csv
    data = @fb_analyzer.analyze_wall
    path = File.join File.expand_path(File.dirname(__FILE__)), "support_files", "test.csv"
    @fb_analyzer.write_data_to_csv(data, path)
    file = Pathname.new path    
    assert(file.exist?)
    FileUtils.rm path
  end

end
